import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  select,
  axisLeft,
  axisBottom,
  csv,
  arc,												
  pie,
  scaleBand,
  scaleLinear,
  max,
  format,
} from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/tharun112/019873eb985912a889aaa592563080e6/raw/6c69f1cd3e7d4b78bbc8712fac7c59571a7f984c/movies_dataset.csv';
const width = 800;
const height = 500;
const margin = {
  top: 20,
  right: 20,
  bottom: 50,
  left: 200,
};

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d.movie_names = d['movie_name'];
      return d;
    };
    csv(csvUrl, row).then((data) => {
      setData(data.slice(0, 5));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight =
    height - margin.top - margin.bottom - 100;
  const innerWidth =
    width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map((d) => d.movie_name))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.imdb_rating)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        {xScale.ticks().map((tickValue) => (
          <g
            key={tickValue}
            transform={`translate(${xScale(
              tickValue
            )},0)`}
          >
            <line
              y2={innerHeight}
              stroke="blue"
            />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map((tickValue) => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".40em"
            y={
              yScale(tickValue) +
              yScale.bandwidth() / 2
            }
          >
            {tickValue}
          </text>
        ))}
        {data.map((d) => (
          <rect
            key={d.movie_names}
            x={0}
            y={yScale(d.movie_names)}
            width={xScale(d.imdb_rating)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById(
  'root'
);
ReactDOM.render(<App />, rootElement);
